@@ -12,7 +12,7 @@ import time
 
 from shutil import copyfile,rmtree
 from stat import * 
-import  .text_tools 
+from .text_tools import *
 
 
 ####################################################################################################
