@@ -1,6 +1,6 @@
 import os
 import re
-import .fs_tools 
+from .fs_tools import *
 
 
 def re_search (re_pattern , text) :
