@@ -123,7 +123,7 @@ def cal_ts_diff(ts1=None, ts2=None):
 
 
 if __name__ == "__main__":
-  #print (get_timestamp(fmt=DEFAULT_TIMESTAMP_FORMAT, epoch_time=1579046194))
+  print (int(get_timestamp(fmt="%H")) + 1)
   #print (get_epoch(get_timestamp()))
   #print (time.time())
   
